# InvitationDataAttributes


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email** | **str** | The email address of the invitee. | [optional] 
**limit_services** | **bool** | Indicates the user has limited access to the customer&#39;s services. | [optional] 
**role** | [**RoleUser**](RoleUser.md) |  | [optional] 
**status_code** | **int** | Indicates whether or not the invitation is active. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


